기능들에 대해
===========

* `디버거를 사용하는 방법에 대해 <debuggers.rst>`_
* `써드파티 패키지들의 설치에 대해 <packages.rst>`_
* `사용자 윈도우 도킹에 대해 <dock.rst>`_
* `터틀 프로그램에 대한 특별한 지원에 대해 <turtle.rst>`_
* `커맨드 라인 인자(아규먼트)들을 이용해 실행하는 것에 대해 <program_arguments.rst>`_
* `간단 모드와 전문가 모드에 대해 <modes.rst>`_
* `쉘에 대해 <shell.rst>`_
* `플로터에 대해 <plotter.rst>`_
* `버드아이에 대해 <birdseye.rst>`_
* `플라스크를 이용한 웹개발에 대해 <flask.rst>`_

일반 주제
==============
* `에러를 다루는 방법 <errors.rst>`_
* `디버깅에 대한 일반적인 조언 <debugging.rst>`_

온라인
======
turcar wiki에 좀 더 많은 정보가 있습니다: https://github.com/turcar/turcar/wiki.

